@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries without C or XS
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -57,10 +57,37 @@ sub new
     lib              => \@lib,
     handles          => {},
     types            => {},
+    lang             => $args{lang} || 'C',
     ignore_not_found => defined $args{ignore_not_found} ? $args{ignore_not_found} : 0,
   }, $class;
 }
 
+sub _type_map
+{
+  my($self) = @_;
+  
+  unless(defined $self->{type_map})
+  {
+    my $class = "FFI::Platypus::Lang::".$self->{lang};
+    unless($class->can("native_type_map"))
+    {
+      eval qq{ use $class };
+      croak "erro loding $class: $@" if $@;
+    }
+    unless($class->can("native_type_map"))
+    {
+      croak "$class does not provide a native_type_map method";
+    }
+    my %type_map = %{ $class->native_type_map };
+    # include the standard libffi types
+    $type_map{$_} = $_ for qw( void sint8 uint8 sint16 uint16 sint32 uint32 sint64 uint64 float double string opaque );
+    $type_map{pointer} = 'opaque';
+    $self->{type_map} = \%type_map;
+  }
+  
+  $self->{type_map};
+}
+
 
 sub lib
 {
@@ -69,6 +96,7 @@ sub lib
   if(@new)
   {
     push @{ $self->{lib} }, @new;
+    delete $self->{mangler};
   }
   
   @{ $self->{lib} };
@@ -88,6 +116,20 @@ sub ignore_not_found
 }
 
 
+sub lang
+{
+  my($self, $value) = @_;
+  
+  if(defined $value)
+  {
+    $self->{lang} = $value;
+    delete $self->{type_map};
+  }
+  
+  $self->{lang};
+}
+
+
 sub type
 {
   my($self, $name, $alias) = @_;
@@ -95,8 +137,7 @@ sub type
   croak "spaces not allowed in alias" if defined $alias && $alias =~ /\s/;
   croak "allowed characters for alias: [A-Za-z0-9_]+" if defined $alias && $alias =~ /[^A-Za-z0-9_]/;
 
-  require FFI::Platypus::ConfigData;
-  my $type_map = FFI::Platypus::ConfigData->config("type_map");
+  my $type_map = $self->_type_map;
 
   croak "alias conflicts with existing type" if defined $alias && (defined $type_map->{$alias} || defined $self->{types}->{$alias});
 
@@ -147,8 +188,7 @@ sub custom_type
   croak "must define at least one of native_to_perl, perl_to_native, or perl_to_native_post"
     unless defined $cb->{native_to_perl} || defined $cb->{perl_to_native} || defined $cb->{perl_to_native_post};
   
-  require FFI::Platypus::ConfigData;
-  my $type_map = FFI::Platypus::ConfigData->config("type_map");  
+  my $type_map = $self->_type_map;
   croak "$type is not a native type" unless defined $type_map->{$type} || $type eq 'string';
   croak "name conflicts with existing type" if defined $type_map->{$name} || defined $self->{types}->{$name};
   
@@ -203,8 +243,7 @@ sub types
 {
   my($self) = @_;
   $self = $self->new unless ref $self && eval { $self->isa('FFI::Platypus') };
-  require FFI::Platypus::ConfigData;
-  my %types = map { $_ => 1 } keys %{ FFI::Platypus::ConfigData->config("type_map") };
+  my %types = map { $_ => 1 } keys %{ $self->_type_map };
   $types{$_} ||= 1 foreach keys %{ $self->{types} };
   sort keys %types;
 }
@@ -290,11 +329,34 @@ sub find_symbol
 {
   my($self, $name) = @_;
 
+  unless(defined $self->{mangler})
+  {
+    my $class = "FFI::Platypus::Lang::".$self->{lang};
+    unless($class->can('native_type_map'))
+    {
+      eval qq{ use $class };
+      croak "unable to load $class: $@" if $@;
+    }
+    if($class->can('mangler'))
+    {
+      $self->{mangler} = $class->mangler($self->lib);
+    }
+    else
+    {
+      $self->{mangler} = sub { $_[0] };
+    }
+  }
+
   foreach my $path (@{ $self->{lib} })
   {
     my $handle = do { no warnings; $self->{handles}->{$path||0} } || FFI::Platypus::dl::dlopen($path);
-    next unless $handle;
-    my $address = FFI::Platypus::dl::dlsym($handle, $name);
+    unless($handle)
+    {
+      warn "error loading $path: ", FFI::Platypus::dl::dlerror()
+        if $ENV{FFI_PLATYPUS_DLERROR};
+      next;
+    }
+    my $address = FFI::Platypus::dl::dlsym($handle, $self->{mangler}->($name));
     if($address)
     {
       $self->{handles}->{$path||0} = $handle;
@@ -348,7 +410,7 @@ sub DESTROY
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -360,7 +422,7 @@ package FFI::Platypus::Closure;
 use Scalar::Util qw( refaddr);
 use Carp qw( croak );
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 our %cbdata;
 
@@ -387,13 +449,13 @@ sub DESTROY
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 sub new
 {
@@ -433,7 +495,7 @@ sub new
       $classname = $1;
       unless($classname->can('ffi_record_size') || $classname->can('_ffi_record_size'))
       {
-        eval qq{ require $classname };
+        eval qq{ use $classname };
         warn "error requiring $classname: $@";
       }
       if($classname->can('ffi_record_size'))
@@ -483,7 +545,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries without C or XS
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -599,6 +661,12 @@ to pre-populate the L<lib|/lib> attribute.
 
 Set the L<ignore_not_found|/ignore_not_found> attribute.
 
+=item lang
+
+[version 0.18]
+
+Set the L<lang|/lang> attribute.
+
 =back
 
 =head1 ATTRIBUTES
@@ -647,6 +715,23 @@ This is useful when you are writing bindings to a library and have many
 optional functions and you do not wish to wrap every call to 
 L<function|/function> or L<attach|/attach> in an C<eval>.
 
+=head2 lang
+
+[version 0.18]
+
+ $ffi->lang($language);
+
+Specifies the foreign language that you will be interfacing with. The 
+default is C.  The foreign language specified with this attribute 
+changes the default native types (for example, if you specify 
+L<Rust|FFI::Platypus::Lang::Rust>, you will get C<i32> as an alias for 
+C<sint32> instead of C<int> as you do with L<C|FFI::Platypus::Lang::C>).
+
+If the foreign language plugin supports it, this will also enable 
+Platypus to find symbols using the demangled names (for example, if you 
+specify L<CPP|FFI::Platypus::Lang::CPP> for C++ you can use method names 
+like C<Foo::get_bar()> with L</attach> or L</function>.
+
 =head1 METHODS
 
 =head2 type
@@ -1482,6 +1567,25 @@ Bundle C code with your FFI extension.
 
 JIT compiler for FFI.
 
+=item L<FFI::Platypus::Lang::C>
+
+Documentation and tools for using Platypus with the C programming 
+language
+
+=item L<FFI::Platypus::Lang::CPP>
+
+Documentation and tools for using Platypus with the C++ programming 
+language
+
+=item L<FFI::Platypus::Lang::Rust>
+
+Documentation and tools for using Platypus with the Rust programming 
+language
+
+=item L<FFI::Platypus::Lang::ASM>
+
+Documentation and tools for using Platypus with the Assembly
+
 =item L<Convert::Binary::C>
 
 An interface for interacting with C C<struct> types.  Unfortunately it 
@@ -1526,9 +1630,9 @@ Another FFI for Perl that doesn't appear to have worked for a long time.
 
 =head1 AUTHOR
 
-author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
