@@ -5,7 +5,7 @@ use warnings;
 use FFI::Platypus;
 
 # ABSTRACT: Declarative interface to FFI::Platypus
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 
 our $ffi    = {};
@@ -85,6 +85,12 @@ sub sizeof ($)
   _ffi_object->sizeof($_[0]);
 }
 
+
+sub lang ($)
+{
+  _ffi_object->lang($_[0]);
+}
+
 sub import
 {
   my $caller = caller;
@@ -127,6 +133,7 @@ sub import
   *{join '::', $caller, 'cast'} = \&cast;
   *{join '::', $caller, 'attach_cast'} = \&attach_cast;
   *{join '::', $caller, 'sizeof'} = \&sizeof;
+  *{join '::', $caller, 'lang'} = \&lang;
 }
 
 1;
@@ -143,7 +150,7 @@ FFI::Platypus::Declare - Declarative interface to FFI::Platypus
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -330,6 +337,19 @@ This function is not very fast, so you might want to save this value as
 a constant, particularly if you need the size in a loop with many 
 iterations.
 
+=head2 lang
+
+ lang $language;
+
+Specifies the foreign language that you will be interfacing with. The 
+default is C.  The foreign language specified with this attribute 
+changes the default native types (for example, if you specify 
+L<Rust|FFI::Platypus::Lang::Rust>, you will get C<i32> as an alias for 
+C<sint32> instead of C<int> as you do with L<C|FFI::Platypus::Lang::C>).
+
+In the future this may attribute may offer hints when doing demangling
+of languages that require it like L<C++|FFI::Platypus::Lang::CPP>.
+
 =head1 SEE ALSO
 
 =over 4
@@ -370,9 +390,9 @@ faster.
 
 =head1 AUTHOR
 
-author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
