@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Documentation and tools for using Platypus with the Assembly
-our $VERSION = '0.99_06'; # TRIAL VERSION
+our $VERSION = '0.18'; # VERSION
 
 
 sub native_type_map
@@ -26,21 +26,17 @@ FFI::Platypus::Lang::ASM - Documentation and tools for using Platypus with the A
 
 =head1 VERSION
 
-version 0.99_06
+version 0.18
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new( api => 1 );
+ my $ffi = FFI::Platypus->new;
  $ffi->lang('ASM');
 
 =head1 DESCRIPTION
 
-Setting your lang to C<ASM> includes no native type aliases, so types
-like C<int> or C<unsigned long> will not work.  You need to specify
-instead C<sint32> or C<sint64>.  Although intended for use with Assembly
-it could also be used for other languages if you did not want to use
-the normal C aliases for native types.
+Setting your lang to C<ASM> removes all non ffi types.  
 
 This document will one day include information on bundling Assembly
 with your Perl / FFI / Platypus distribution.  Pull requests welcome!
@@ -49,11 +45,11 @@ with your Perl / FFI / Platypus distribution.  Pull requests welcome!
 
 =head2 native_type_map
 
- my $hashref = FFI::Platypus::Lang::ASM->native_type_map;
+ my $hashref = FFI::Platypus::Lang::C->native_type_map;
 
-This returns an empty hash reference.  For other languages it returns
-a hash reference that defines the aliases for the types normally used
-for that language.
+This returns a hash reference containing the native aliases for the
+C programming languages.  That is the keys are native C types and the
+values are libffi native types.
 
 =head1 SEE ALSO
 
@@ -65,6 +61,8 @@ The Core Platypus documentation.
 
 =back
 
+=cut
+
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
@@ -73,35 +71,9 @@ Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
-Dylan Cali (calid)
-
-pipcet
-
-Zaki Mughal (zmughal)
-
-Fitz Elliott (felliott)
-
-Vickenty Fesunov (vyf)
-
-Gregor Herrmann (gregoa)
-
-Shlomi Fish (shlomif)
-
-Damyan Ivanov
-
-Ilya Pavlov (Ilya33)
-
-Petr Pisar (ppisar)
-
-Mohammad S Anwar (MANWAR)
-
-Håkon Hægland (hakonhagland, HAKONH)
-
-Meredith (merrilymeredith, MHOWARD)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
