@@ -4,13 +4,13 @@ use strict;
 use warnings;
 
 # ABSTRACT: Documentation and tools for using Platypus with the C programming language
-our $VERSION = '0.99_06'; # TRIAL VERSION
+our $VERSION = '0.18'; # VERSION
 
 
 sub native_type_map
 {
-  require FFI::Platypus::ShareConfig;
-  FFI::Platypus::ShareConfig->get('type_map');
+  require FFI::Platypus::ConfigData;
+  FFI::Platypus::ConfigData->config('type_map');
 }
 
 1;
@@ -27,19 +27,19 @@ FFI::Platypus::Lang::C - Documentation and tools for using Platypus with the C p
 
 =head1 VERSION
 
-version 0.99_06
+version 0.18
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new( api => 1 );
+ my $ffi = FFI::Platypus->new;
  $ffi->lang('C'); # the default
 
 =head1 DESCRIPTION
 
-This module provides some hooks for Platypus to interact with the C
-programming language.  It is generally used by default if you do not
-specify another foreign programming language with the
+This module provides some hooks for Platypus to interact with the C 
+programming language.  It is generally used by default if you do not 
+specify another foreign programming language with the 
 L<FFI::Platypus#lang> attribute.
 
 =head1 METHODS
@@ -62,6 +62,8 @@ The Core Platypus documentation.
 
 =back
 
+=cut
+
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
@@ -70,35 +72,9 @@ Contributors:
 
 Bakkiaraj Murugesan (bakkiaraj)
 
-Dylan Cali (calid)
-
-pipcet
-
-Zaki Mughal (zmughal)
-
-Fitz Elliott (felliott)
-
-Vickenty Fesunov (vyf)
-
-Gregor Herrmann (gregoa)
-
-Shlomi Fish (shlomif)
-
-Damyan Ivanov
-
-Ilya Pavlov (Ilya33)
-
-Petr Pisar (ppisar)
-
-Mohammad S Anwar (MANWAR)
-
-Håkon Hægland (hakonhagland, HAKONH)
-
-Meredith (merrilymeredith, MHOWARD)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
